Learn R Programming

hcandersenr (version 0.2.0)

hca_fairytales: Tidy data frame of all of H.C. Andersens fairy tales in this pacakage

Description

A tidy data frame of all of H.C. Andersens fairy tales in this pacakage with three columns: text, which contains the text of the fairy tales divided into elements of up to about 80 characters each, book, which contains the titles of the fairy tales in english, and language which is the language of the text.

Usage

hca_fairytales()

Arguments

Format

A data frame with three variables: text, book and language.

Examples

Run this code
# NOT RUN {
tales <- hca_fairytales()

# See first few rows
head(tales)

# }

Run the code above in your browser using DataLab